/*
** Copyright (C) 2001 Martin Roesch <roesch@sourcefire.com>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifdef WIN32

#include <io.h>
#include <stdio.h>
#include <string.h>
#include <winsock.h>
#include <sys/timeb.h>
#include <time.h>


/****************************************************************************
 *
 * Function: gettimeofday(struct timeval *, struct timezone *)
 *
 * Purpose:  Get current time of day.
 *
 * Arguments: tv => Place to store the curent time of day.
 *            tz => Ignored.
 *
 * Returns: 0 => Success.
 *
 ****************************************************************************/

int gettimeofday(struct timeval *tv, struct timezone *tz) {
    struct _timeb tb;

	if(tv==NULL) return -1;
	_ftime(&tb);
	tv->tv_sec = tb.time;
	tv->tv_usec = ((int) tb.millitm) * 1000;
	return 0;
}


/****************************************************************************
 *
 * Function: init_winsock(void)
 *
 * Purpose:  Initialize winsock.
 *
 * Arguments: None.
 *
 * Returns: 0 => Initilization failed.
 *          1 => Initilization succeeded.
 *
 ****************************************************************************/

int init_winsock(void) {
  WORD wVersionRequested = MAKEWORD(1, 1);
  WSADATA wsaData;

  if (WSAStartup(wVersionRequested, &wsaData)) {
    fprintf(stderr,"[!] ERROR: Unable to find a usable Winsock.\n");
    return 0;
  }

  if (LOBYTE(wsaData.wVersion) < 1 || HIBYTE(wsaData.wVersion) < 1) {
    fprintf(stderr,"[!] ERROR: Unable to find Winsock version 1.1 or greater. You have version %d.%d.\n",
	    LOBYTE(wsaData.wVersion), HIBYTE(wsaData.wVersion));
    WSACleanup();
    return 0;
  }
	
  return 1;
}	

int geteuid(void) {
	return 0;
}

int getpid(void) {
	return 0;
}

int link(char *source, char *dest)
{	return 0;
}

// Based on a rip from WinDump found in snort
void PrintDeviceList(const char* device)
{
	const WCHAR* t;
    int i=0,x;
    int DescPos=0;
    char *Desc;
    int n=1;

	fprintf(stderr,"Available Interfaces (for -i option):\n\nI/F   Device\t\t      Description\n");
	for(x=0;x<65;x++) 
		fprintf(stderr,"-");

	t=(WCHAR*)device;
	while(*(t+DescPos)!=0 || *(t+DescPos-1)!=0){
		DescPos++;
	}
	DescPos<<=1;
	Desc=(char*)t+DescPos+2;
	fprintf(stderr,"\n%3d   ",n++);

	while (!(t[i]==0 && t[i-1]==0))
	{
		if (t[i]==0)
		{
			fprintf(stderr," (");
			while(*Desc!=0){
				fprintf(stderr,"%c",*Desc);
				Desc++;
			}
			Desc++;
			fprintf(stderr,")\n");
		}
		else fprintf(stderr,"%c",t[i]);

		if(t[i]==0 && t[i+1]!=0)
			fprintf(stderr,"\n%3d   ",n++);
		i++;
	}
	fprintf(stderr,"\n");
}

void *GetAdapterFromList(void *device,int index) 
{	WCHAR *Adapter;
    int i;

	Adapter=(WCHAR *)device;
	for(i = 0;i < index - 1; i++){
		while(*Adapter++ != 0);
		if(*Adapter == 0)
			return NULL;
	}
	return  Adapter;
}

unsigned long getnetmask(char *netstr)  /* returns a subnet mask (i.e. /24) as a long (i.e. 0xffffff00) */
{	int netbits,i;
	unsigned long net=0;

	netbits=atol(netstr);
	if(netbits<=0 || netbits>32)
		netbits=32;
	for(i=0;i<32;i++)
	{	net<<=1;
		if(i<netbits)
			net|=1;		
	}
	return htonl(net);
}


#endif
